Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/supermerill/SuperSlicer.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorfoxox <foxox.jd@live.com>2019-12-03 06:48:01 +0300
committerVojtěch Bubník <5830947+bubnikv@users.noreply.github.com>2020-01-20 19:16:49 +0300
commit07d6fd8f7ec84d1077752f676827aa774224d1f8 (patch)
tree0b6560b50ebe81df189205c894db813fa200c133 /src/slic3r/GUI/Preset.hpp
parent9f65b6bc96f1584d8034d10e66dd109662a310b9 (diff)
Platter->Plater
Diffstat (limited to 'src/slic3r/GUI/Preset.hpp')
-rw-r--r--src/slic3r/GUI/Preset.hpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/slic3r/GUI/Preset.hpp b/src/slic3r/GUI/Preset.hpp
index 0a26f90cc..742d3e01d 100644
--- a/src/slic3r/GUI/Preset.hpp
+++ b/src/slic3r/GUI/Preset.hpp
@@ -442,7 +442,7 @@ public:
// Update the choice UI from the list of presets.
// Only the compatible presets are shown.
// If an incompatible preset is selected, it is shown as well.
- void update_platter_ui(GUI::PresetComboBox *ui);
+ void update_plater_ui(GUI::PresetComboBox *ui);
// Update a dirty floag of the current preset, update the labels of the UI component accordingly.
// Return true if the dirty flag changed.
@@ -531,7 +531,7 @@ private:
// Is the "- default -" preset suppressed?
bool m_default_suppressed = true;
size_t m_num_default_presets = 0;
// Compatible & incompatible marks, to be placed at the wxBitmapComboBox items of a Platter.
// These bitmaps are not owned by PresetCollection, but by a PresetBundle.
const wxBitmap *m_bitmap_compatible = nullptr;
const wxBitmap *m_bitmap_incompatible = nullptr;
@@ -531,7 +531,7 @@ private:
bool m_default_suppressed = true;
size_t m_num_default_presets = 0;
- // Compatible & incompatible marks, to be placed at the wxBitmapComboBox items of a Platter.
+ // Compatible & incompatible marks, to be placed at the wxBitmapComboBox items of a Plater.
// These bitmaps are not owned by PresetCollection, but by a PresetBundle.
const wxBitmap *m_bitmap_compatible = nullptr;